@@ -1529,16 +1529,16 @@ static void tangle_actor_dispose(GObject* object) {
 		actor->priv->animations = NULL;
 	}
 
-	TANGLE_UNREF_AND_NULLIFY_OBJECT_POINTER(actor->priv->button_press_action);
-	TANGLE_UNREF_AND_NULLIFY_OBJECT_POINTER(actor->priv->button_release_action);
-	TANGLE_UNREF_AND_NULLIFY_OBJECT_POINTER(actor->priv->enter_action);
-	TANGLE_UNREF_AND_NULLIFY_OBJECT_POINTER(actor->priv->leave_action);
-	TANGLE_UNREF_AND_NULLIFY_OBJECT_POINTER(actor->priv->motion_action);
-	TANGLE_UNREF_AND_NULLIFY_OBJECT_POINTER(actor->priv->scroll_action);
-	TANGLE_UNREF_AND_NULLIFY_OBJECT_POINTER(actor->priv->hide_action);
-	TANGLE_UNREF_AND_NULLIFY_OBJECT_POINTER(actor->priv->show_action);
-	TANGLE_UNREF_AND_NULLIFY_OBJECT_POINTER(actor->priv->show_completed_action);
-	TANGLE_UNREF_AND_NULLIFY_OBJECT_POINTER(actor->priv->transition_completed_action);
+	TANGLE_UNREF_AND_NULLIFY_OBJECT(actor->priv->button_press_action);
+	TANGLE_UNREF_AND_NULLIFY_OBJECT(actor->priv->button_release_action);
+	TANGLE_UNREF_AND_NULLIFY_OBJECT(actor->priv->enter_action);
+	TANGLE_UNREF_AND_NULLIFY_OBJECT(actor->priv->leave_action);
+	TANGLE_UNREF_AND_NULLIFY_OBJECT(actor->priv->motion_action);
+	TANGLE_UNREF_AND_NULLIFY_OBJECT(actor->priv->scroll_action);
+	TANGLE_UNREF_AND_NULLIFY_OBJECT(actor->priv->hide_action);
+	TANGLE_UNREF_AND_NULLIFY_OBJECT(actor->priv->show_action);
+	TANGLE_UNREF_AND_NULLIFY_OBJECT(actor->priv->show_completed_action);
+	TANGLE_UNREF_AND_NULLIFY_OBJECT(actor->priv->transition_completed_action);
 
 	if (actor->priv->ancestor_events) {
 		g_list_foreach(actor->priv->ancestor_events, (GFunc)tangle_event_free, NULL);
