@@ -54,11 +54,14 @@ GType tangle_draggable_actor_get_type(void) G_GNUC_CONST;
 
 ClutterActor* tangle_draggable_actor_new(ClutterActor* wrapped);
 
-gfloat tangle_draggable_actor_get_dragging_treshold_x(TangleDraggableActor* draggable_actor);
-void tangle_draggable_actor_set_dragging_treshold_x(TangleDraggableActor* draggable_actor, gfloat dragging_threshold_x);
-gfloat tangle_draggable_actor_get_dragging_treshold_y(TangleDraggableActor* draggable_actor);
-void tangle_draggable_actor_set_dragging_treshold_y(TangleDraggableActor* draggable_actor, gfloat dragging_threshold_y);
-void tangle_draggable_actor_set_dragging_treshold(TangleDraggableActor* draggable_actor, gfloat dragging_threshold);
+gboolean tangle_draggable_actor_get_dragging_enabled(TangleDraggableActor* draggable_actor);
+void tangle_draggable_actor_set_dragging_enabled(TangleDraggableActor* draggable_actor, gboolean dragging_enabled);
+
+gfloat tangle_draggable_actor_get_dragging_threshold_x(TangleDraggableActor* draggable_actor);
+void tangle_draggable_actor_set_dragging_threshold_x(TangleDraggableActor* draggable_actor, gfloat dragging_threshold_x);
+gfloat tangle_draggable_actor_get_dragging_threshold_y(TangleDraggableActor* draggable_actor);
+void tangle_draggable_actor_set_dragging_threshold_y(TangleDraggableActor* draggable_actor, gfloat dragging_threshold_y);
+void tangle_draggable_actor_set_dragging_threshold(TangleDraggableActor* draggable_actor, gfloat dragging_threshold);
 
 #define TANGLE_TYPE_DRAGGING (tangle_dragging_get_type())
 #define TANGLE_DRAGGING(p) ((TangleDragging*)(p))
