@@ -15,6 +15,7 @@
 #include <string.h>
 #include <clutter/clutter.h>
 #include <gmodule.h>
+#include <glib.h>
 
 /**
  * SECTION:tangle-misc
@@ -22,24 +23,69 @@
  * @Title: Miscellaneous utilities
  */
 
+static GHashTable* calculation_functions_hash_table = NULL;
+
 static void on_weak_notify(gpointer user_data, GObject* other_object);
 
+#define DEFINE_CALCULATION_FUNCTIONS(t) \
+	static void add_##t(GValue* value, GValue* addend) { g##t v; g##t a; \
+	v = g_value_get_##t(value); a = g_value_get_##t(addend); \
+	v += a; g_value_set_##t(value, v); \
+	} \
+	static void substract_##t(GValue* value, GValue* addend) { g##t v; g##t a; \
+	v = g_value_get_##t(value); a = g_value_get_##t(addend); \
+	v -= a; g_value_set_##t(value, v); \
+	} \
+	static void multiply_##t(GValue* value, GValue* addend) { g##t v; g##t a; \
+	v = g_value_get_##t(value); a = g_value_get_##t(addend); \
+	v *= a; g_value_set_##t(value, v); \
+	} \
+	static void divide_##t(GValue* value, GValue* addend) { g##t v; g##t a; \
+	v = g_value_get_##t(value); a = g_value_get_##t(addend); \
+	v /= a; g_value_set_##t(value, v); \
+	} \
+	static TangleValueCalculationFunctions calculation_functions_##t = { \
+	add_##t, substract_##t, multiply_##t, divide_##t };
+
+DEFINE_CALCULATION_FUNCTIONS(char)
+DEFINE_CALCULATION_FUNCTIONS(uchar)
+DEFINE_CALCULATION_FUNCTIONS(int)
+DEFINE_CALCULATION_FUNCTIONS(uint)
+DEFINE_CALCULATION_FUNCTIONS(long)
+DEFINE_CALCULATION_FUNCTIONS(ulong)
+DEFINE_CALCULATION_FUNCTIONS(int64)
+DEFINE_CALCULATION_FUNCTIONS(uint64)
+DEFINE_CALCULATION_FUNCTIONS(float)
+DEFINE_CALCULATION_FUNCTIONS(double)
+
 gboolean tangle_init(int* argc, char*** argv) {
 	gboolean success = FALSE;
 	TangleStylesheet* stylesheet;
 	
 	if (clutter_init(argc, argv) == CLUTTER_INIT_SUCCESS) {
+		tangle_value_register_calculation_functions(G_TYPE_CHAR, &calculation_functions_char);
+		tangle_value_register_calculation_functions(G_TYPE_UCHAR, &calculation_functions_uchar);
+		tangle_value_register_calculation_functions(G_TYPE_INT, &calculation_functions_int);
+		tangle_value_register_calculation_functions(G_TYPE_UINT, &calculation_functions_uint);
+		tangle_value_register_calculation_functions(G_TYPE_LONG, &calculation_functions_long);
+		tangle_value_register_calculation_functions(G_TYPE_ULONG, &calculation_functions_ulong);
+		tangle_value_register_calculation_functions(G_TYPE_INT64, &calculation_functions_int64);
+		tangle_value_register_calculation_functions(G_TYPE_UINT64, &calculation_functions_uint64);
+		tangle_value_register_calculation_functions(G_TYPE_FLOAT, &calculation_functions_float);
+		tangle_value_register_calculation_functions(G_TYPE_DOUBLE, &calculation_functions_double);
+
 		success = TRUE;
 	}
 	
 	return success;
 }
 
-void tangle_unref_and_nullify_object_pointer_impl(GObject** object_pointer) {
-	if (*object_pointer) {
-		g_object_unref(*object_pointer);
-		*object_pointer = NULL;
+gpointer tangle_unref_object(gpointer object) {
+	if (object) {
+		g_object_unref(object);
 	}
+	
+	return NULL;
 }
 
 TanglePointers* tangle_pointers_new(gint n, ...) {
@@ -281,6 +327,77 @@ gboolean tangle_signal_connect_dynamically_from_script(GObject* object, const gc
 	return retvalue;
 }
 
+void tangle_value_add(GValue* value, GValue* addend) {
+	TangleValueCalculationFunctions* calculation_functions;
+	
+	g_return_if_fail(G_VALUE_TYPE(value) == G_VALUE_TYPE(addend));
+	
+	if (!calculation_functions_hash_table || !(calculation_functions = (TangleValueCalculationFunctions*)g_hash_table_lookup(calculation_functions_hash_table, GUINT_TO_POINTER(G_VALUE_TYPE(value))))) {
+		g_critical("No calculation functions for value type '%s'.", G_VALUE_TYPE_NAME(value));
+	} else if (!calculation_functions->add) {
+		g_critical("No add function for value type '%s'.", G_VALUE_TYPE_NAME(value));	
+	} else {
+		calculation_functions->add(value, addend);
+	}
+}
+
+void tangle_value_substract(GValue* value, GValue* subtrahend) {
+	TangleValueCalculationFunctions* calculation_functions;
+	
+	g_return_if_fail(G_VALUE_TYPE(value) == G_VALUE_TYPE(subtrahend));
+	
+	if (!calculation_functions_hash_table || !(calculation_functions = (TangleValueCalculationFunctions*)g_hash_table_lookup(calculation_functions_hash_table, GUINT_TO_POINTER(G_VALUE_TYPE(value))))) {
+		g_critical("No calculation functions for value type '%s'.", G_VALUE_TYPE_NAME(value));
+	} else if (!calculation_functions->substract) {
+		g_critical("No substract function for value type '%s'.", G_VALUE_TYPE_NAME(value));	
+	} else {
+		calculation_functions->substract(value, subtrahend);
+	}
+}
+
+void tangle_value_multiply(GValue* value, GValue* multiplier) {
+	TangleValueCalculationFunctions* calculation_functions;
+	
+	g_return_if_fail(G_VALUE_TYPE(value) == G_VALUE_TYPE(multiplier));
+	
+	if (!calculation_functions_hash_table || !(calculation_functions = (TangleValueCalculationFunctions*)g_hash_table_lookup(calculation_functions_hash_table, GUINT_TO_POINTER(G_VALUE_TYPE(value))))) {
+		g_critical("No calculation functions for value type '%s'.", G_VALUE_TYPE_NAME(value));
+	} else if (!calculation_functions->multiply) {
+		g_critical("No multiply function for value type '%s'.", G_VALUE_TYPE_NAME(value));	
+	} else {
+		calculation_functions->multiply(value, multiplier);
+	}
+}
+
+void tangle_value_divide(GValue* value, GValue* divider) {
+	TangleValueCalculationFunctions* calculation_functions;
+	
+	g_return_if_fail(G_VALUE_TYPE(value) == G_VALUE_TYPE(divider));
+	
+	if (!calculation_functions_hash_table || !(calculation_functions = (TangleValueCalculationFunctions*)g_hash_table_lookup(calculation_functions_hash_table, GUINT_TO_POINTER(G_VALUE_TYPE(value))))) {
+		g_critical("No calculation functions for value type '%s'.", G_VALUE_TYPE_NAME(value));
+	} else if (!calculation_functions->divide) {
+		g_critical("No divide function for value type '%s'.", G_VALUE_TYPE_NAME(value));	
+	} else {
+		calculation_functions->divide(value, divider);
+	}
+}
+
+void tangle_value_register_calculation_functions(GType value_type, TangleValueCalculationFunctions* calculation_functions) {
+	TangleValueCalculationFunctions* calculation_functions_copy;
+
+	if (calculation_functions_hash_table && g_hash_table_lookup(calculation_functions_hash_table, GUINT_TO_POINTER(value_type))) {
+		g_critical("Calculation functions already exists for value type '%s'.", g_type_name(value_type));
+	} else {
+		if (!calculation_functions_hash_table) {
+			calculation_functions_hash_table = g_hash_table_new(NULL, NULL);
+		}
+		calculation_functions_copy = g_new(TangleValueCalculationFunctions, 1);
+		*calculation_functions_copy = *calculation_functions;
+		g_hash_table_insert(calculation_functions_hash_table, GUINT_TO_POINTER(value_type), calculation_functions_copy);
+	}
+}
+
 static void on_weak_notify(gpointer user_data, GObject* other_object) {
 	TangleVault* vault;
 	GObject* object;
