@@ -14,12 +14,18 @@
 #include <glib-object.h>
 #include <clutter/clutter.h>
 
+typedef struct _TangleValueCalculationFunctions {
+	void (*add)(GValue* value, GValue* addend);
+	void (*substract)(GValue* value, GValue* subtrahend);
+	void (*multiply)(GValue* value, GValue* multiplier);
+	void (*divide)(GValue* value, GValue* divider);
+} TangleValueCalculationFunctions;
+
 gboolean tangle_init(int* argc, char*** argv);
 
-#define TANGLE_UNREF_AND_NULLIFY_OBJECT_POINTER(x) tangle_unref_and_nullify_object_pointer_impl((GObject**)&(x))
-#define TANGLE_UNREF_OBJECT(x) (x ? g_object_unref(x) : ; )
+#define TANGLE_UNREF_AND_NULLIFY_OBJECT(x) ((x) = tangle_unref_object(x))
 
-void tangle_unref_and_nullify_object_pointer_impl(GObject** object_pointer);
+gpointer tangle_unref_object(gpointer object);
 
 typedef gpointer TanglePointers;
 
@@ -40,4 +46,12 @@ gboolean tangle_signal_connect_object_swapped_dynamically(GObject* object, const
 
 gboolean tangle_signal_connect_dynamically_from_script(GObject* object, const gchar* signal_name, const gchar* function_name, ClutterScript* script);
 
+void tangle_value_add(GValue* value, GValue* addend);
+void tangle_value_substract(GValue* value, GValue* subtrahend);
+void tangle_value_multiply(GValue* value, GValue* multiplier);
+void tangle_value_divide(GValue* value, GValue* divider);
+
+void tangle_value_register_calculation_functions(GType value_type, TangleValueCalculationFunctions* calculation_functions);
+
+
 #endif
