@@ -927,6 +927,12 @@ static void handle_event(TangleScrollingActor* scrolling_actor, Axis axis, gfloa
 		}
 
 		scrolling_actor->priv->previous_motion_time = event_time;
+	} else if (release) {
+		if (axis == HORIZONTAL) {
+			tangle_scrolling_actor_clamp_scrolling_offset_x(scrolling_actor);
+		} else {
+			tangle_scrolling_actor_clamp_scrolling_offset_y(scrolling_actor);
+		}	
 	}
 }
 
