@@ -310,7 +310,7 @@ static void tangle_style_dispose(GObject* object) {
 	
 	style = TANGLE_STYLE(object);
 	
-	TANGLE_UNREF_AND_NULLIFY_OBJECT_POINTER(style->priv->style_properties);
+	TANGLE_UNREF_AND_NULLIFY_OBJECT(style->priv->style_properties);
 	
 	G_OBJECT_CLASS(tangle_style_parent_class)->dispose(object);
 }
