@@ -39,7 +39,6 @@ struct _TangleTemplatePrivate {
 	GType object_type;
 	GHashTable* parameters;
 	
-	ClutterScript* script;
 	guint instance_counter;
 };
 
@@ -72,6 +71,7 @@ GObject* tangle_template_create_object(TangleTemplate* template) {
 	GArray* nonconstruct_parameters;
 	GArray* signal_parameters;
 	gpointer type_class;
+	ClutterScript* script;
 	guint i;
 	GParamSpec* param_spec;
 	const gchar* template_id;
@@ -104,8 +104,10 @@ GObject* tangle_template_create_object(TangleTemplate* template) {
 	if (!error) {
 		object = g_object_newv(template->priv->object_type, construct_parameters->len, (GParameter*)construct_parameters->data);
 		
+		script = tangle_object_get_script(TANGLE_OBJECT(template));
+		
 		template->priv->instance_counter++;
-		if (template->priv->script) {
+		if (script) {
 			if ((template_id = clutter_get_script_id(G_OBJECT(template)))) {
 				id = g_strdup_printf("%s$%d", template_id, template->priv->instance_counter);
 				if (CLUTTER_IS_SCRIPTABLE(object)) {
@@ -116,11 +118,11 @@ GObject* tangle_template_create_object(TangleTemplate* template) {
 				}
 			}
 			if (TANGLE_IS_ACTOR(object)) {
-				_tangle_actor_set_script(TANGLE_ACTOR(object), template->priv->script);
+				_tangle_actor_set_script(TANGLE_ACTOR(object), script);
 			}
 		}
 		
-		if (!template->priv->script ||
+		if (!script ||
 		    !CLUTTER_IS_SCRIPTABLE(object) ||
 		    !(scriptable = CLUTTER_SCRIPTABLE(object)) ||
 		    !(scriptable_iface = CLUTTER_SCRIPTABLE_GET_IFACE(scriptable)) ||
@@ -130,7 +132,7 @@ GObject* tangle_template_create_object(TangleTemplate* template) {
 		for (i = 0; i < nonconstruct_parameters->len; i++) {
 			parameter = &g_array_index(nonconstruct_parameters, GParameter, i);
 			if (scriptable_iface) {
-				scriptable_iface->set_custom_property(scriptable, template->priv->script, parameter->name, &parameter->value);
+				scriptable_iface->set_custom_property(scriptable, script, parameter->name, &parameter->value);
 			} else {
 				g_object_set_property(object, parameter->name, &parameter->value);
 			}
@@ -140,8 +142,8 @@ GObject* tangle_template_create_object(TangleTemplate* template) {
 			parameter = &g_array_index(signal_parameters, GParameter, i);
 			if (!G_VALUE_HOLDS(&parameter->value, G_TYPE_STRING) || !substitute_parameters(template, &parameter->value)) {
 				g_warning("Failed to connect the signal handler property '%s' of an object created from the template '%s', skipped.", parameter->name + 1, clutter_get_script_id(G_OBJECT(template)));
-			} else if (template->priv->script) {
-				if (!!tangle_signal_connect_dynamically_from_script(object, parameter[i].name + 1, g_value_get_string(&parameter->value), template->priv->script)) {
+			} else if (script) {
+				if (!!tangle_signal_connect_dynamically_from_script(object, parameter[i].name + 1, g_value_get_string(&parameter->value), script)) {
 					g_warning("Failed to connect the signal handler property '%s' of an object created from the template '%s', skipped.", parameters->name + 1, clutter_get_script_id(G_OBJECT(template)));
 				}
 			} else if (!tangle_signal_connect_dynamically(object, parameter[i].name + 1, g_value_get_string(&parameter->value), NULL)) {
@@ -397,13 +399,8 @@ static gboolean tangle_template_parse_custom_node(ClutterScriptable* scriptable,
 	GList* name_list_item;
 	
 	template = TANGLE_TEMPLATE(scriptable);
-	g_assert(!template->priv->script || template->priv->script == script);
+	_tangle_object_set_script(TANGLE_OBJECT(template), script);
 
-	if (!template->priv->script) {
-		/* TODO: This should be weak, should it not? */
-		g_object_ref(script);
-		template->priv->script = script;
-	}
 	if (name[0] == '@') {
 		retvalue = clutter_script_parse_node(script, value, name, node, NULL);
 	} else if (strcmp(name, "object-type") && strcmp(name, "object-type-name")) {
@@ -445,17 +442,12 @@ static gboolean tangle_template_parse_custom_node(ClutterScriptable* scriptable,
 	return retvalue;
 }
 
-static void tangle_template_set_custom_property(ClutterScriptable* scriptable, ClutterScript* script, const gchar* name, const GValue* value) {
-	tangle_properties_set_property(TANGLE_PROPERTIES(scriptable), name, value);	
-}
-
 static void clutter_scriptable_iface_init(ClutterScriptableIface* iface) {
 	if (!(parent_scriptable_iface = parent_scriptable_iface = g_type_interface_peek_parent (iface))) {
 		parent_scriptable_iface = g_type_default_interface_peek(CLUTTER_TYPE_SCRIPTABLE);
 	}
 	
 	iface->parse_custom_node = tangle_template_parse_custom_node;
-	iface->set_custom_property = tangle_template_set_custom_property;
 }
 
 static gboolean is_value_null(gpointer key, gpointer value, gpointer user_data) {
@@ -542,6 +534,7 @@ static void set_property(const gchar* name, const GValue* value, gpointer user_d
 	gulong mode;
 	guint duration;
 	GValue v = { 0 };
+	ClutterScript* script;
 	
 	vault = TANGLE_VAULT(user_data);
 	tangle_vault_get(vault, 4, TANGLE_TYPE_TEMPLATE, &template, G_TYPE_OBJECT, &object, G_TYPE_ULONG, &mode, G_TYPE_UINT, &duration);
@@ -551,8 +544,8 @@ static void set_property(const gchar* name, const GValue* value, gpointer user_d
 	if (name[0] == '@') {
 		if (!G_VALUE_HOLDS(&v, G_TYPE_STRING) || !substitute_parameters(template, &v)) {
 			g_warning("Failed to connect signal handler property '%s' of an object (id: %s).", name, clutter_get_script_id(G_OBJECT(object)));
-		} else if (template->priv->script) {
-			if (!tangle_signal_connect_dynamically_from_script(object, name + 1, g_value_get_string(&v), template->priv->script)) {
+		} else if ((script = tangle_object_get_script(TANGLE_OBJECT(template)))) {
+			if (!tangle_signal_connect_dynamically_from_script(object, name + 1, g_value_get_string(&v), script)) {
 				g_warning("Failed to connect the signal handler property '%s' of an object created from the template '%s', skipped.", name + 1, clutter_get_script_id(G_OBJECT(template)));
 			}
 		} else if (!tangle_signal_connect_dynamically(object, name + 1, g_value_get_string(&v), NULL)) {
@@ -597,7 +590,7 @@ static gboolean apply_parameters(TangleTemplate* template, const gchar* name, GV
 		if ((param_spec = g_object_class_find_property(G_OBJECT_CLASS(type_class), name)) && G_IS_PARAM_SPEC_OBJECT(param_spec)) {
 			/* Handle deferred object resolution. */
 			substitute_parameters(template, value);
-			if ((object = clutter_script_get_object(template->priv->script, g_value_get_string(value)))) {
+			if ((object = clutter_script_get_object(tangle_object_get_script(TANGLE_OBJECT(template)), g_value_get_string(value)))) {
 				if (TANGLE_IS_TEMPLATE(object) && !G_VALUE_HOLDS(value, TANGLE_TYPE_TEMPLATE)) {
 					/* Create objects from templates recursively. */
 					t = TANGLE_TEMPLATE(object);
