@@ -223,8 +223,9 @@ static void tangle_wrapper_actor_set_property(GObject* object, guint prop_id, co
 	switch (prop_id) {
 		case PROP_WRAPPED:
 			wrapper_actor->priv->wrapped = CLUTTER_ACTOR(g_value_get_object(value));
-			g_object_ref_sink(wrapper_actor->priv->wrapped);
+			clutter_actor_push_internal(CLUTTER_ACTOR(wrapper_actor));
 			clutter_actor_set_parent(wrapper_actor->priv->wrapped, CLUTTER_ACTOR(wrapper_actor));
+			clutter_actor_pop_internal(CLUTTER_ACTOR(wrapper_actor));
 			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
@@ -253,8 +254,7 @@ static void tangle_wrapper_actor_dispose(GObject* object) {
 	wrapper_actor = TANGLE_WRAPPER_ACTOR(object);
 	
 	if (wrapper_actor->priv->wrapped) {
-		clutter_actor_destroy(wrapper_actor->priv->wrapped);
-		g_object_unref(wrapper_actor->priv->wrapped);
+		clutter_actor_unparent(wrapper_actor->priv->wrapped);
 		wrapper_actor->priv->wrapped = NULL;
 	}
 
