@@ -26,6 +26,9 @@ int main(int argc, char** argv) {
 	 clutter_texture_new_from_file("test_image_selected_100x74.jpg", NULL));
 	g_signal_connect(clutter_actor, "clicked", G_CALLBACK(on_button_clicked), NULL);
 	draggable_actor = tangle_draggable_actor_new(clutter_actor);
+	/* tangle_draggable_actor_set_dragging_enabled(TANGLE_DRAGGABLE_ACTOR(draggable_actor), FALSE); */
+	tangle_draggable_actor_set_dragging_threshold_x(TANGLE_DRAGGABLE_ACTOR(draggable_actor), 30.0);
+	tangle_draggable_actor_set_dragging_threshold_y(TANGLE_DRAGGABLE_ACTOR(draggable_actor), 20.0);
 	clutter_container_add_actor(CLUTTER_CONTAINER(container), draggable_actor);
 
 	clutter_actor = clutter_texture_new_from_file("test_image_135x100.jpg", NULL);
