@@ -20,8 +20,7 @@ int main(int argc, char** argv) {
 	g_value_init(&value, CLUTTER_TYPE_COLOR);
 	clutter_value_set_color(&value, color);
 	
-	style = tangle_style_new();
-	tangle_style_set_for_class(style, "ClutterRectangle");
+	style = tangle_style_new(CLUTTER_TYPE_RECTANGLE);
 	tangle_style_set_style_property(style, "color", &value);
 
 	stylesheet = tangle_stylesheet_new();
